{"polar",gsl_complex_polar_wrap,METH_VARARGS},
{"rect",gsl_complex_rect_wrap,METH_VARARGS},
{"abs",gsl_complex_abs_wrap,METH_VARARGS},
{"abs2",gsl_complex_abs2_wrap,METH_VARARGS},
{"logabs",gsl_complex_logabs_wrap,METH_VARARGS},
{"add",gsl_complex_add_wrap,METH_VARARGS},
{"sub",gsl_complex_sub_wrap,METH_VARARGS},
{"mul",gsl_complex_mul_wrap,METH_VARARGS},
{"div",gsl_complex_div_wrap,METH_VARARGS},
{"add_real",gsl_complex_add_real_wrap,METH_VARARGS},
{"sub_real",gsl_complex_sub_real_wrap,METH_VARARGS},
{"mul_real",gsl_complex_mul_real_wrap,METH_VARARGS},
{"div_real",gsl_complex_div_real_wrap,METH_VARARGS},
{"add_imag",gsl_complex_add_imag_wrap,METH_VARARGS},
{"sub_imag",gsl_complex_sub_imag_wrap,METH_VARARGS},
{"mul_imag",gsl_complex_mul_imag_wrap,METH_VARARGS},
{"div_imag",gsl_complex_div_imag_wrap,METH_VARARGS},
{"conjugate",gsl_complex_conjugate_wrap,METH_VARARGS},
{"inverse",gsl_complex_inverse_wrap,METH_VARARGS},
{"negative",gsl_complex_negative_wrap,METH_VARARGS},
{"sqrt",gsl_complex_sqrt_wrap,METH_VARARGS},
{"sqrt_real",gsl_complex_sqrt_real_wrap,METH_VARARGS},
{"pow",gsl_complex_pow_wrap,METH_VARARGS},
{"pow_real",gsl_complex_pow_real_wrap,METH_VARARGS},
{"exp",gsl_complex_exp_wrap,METH_VARARGS},
{"log",gsl_complex_log_wrap,METH_VARARGS},
{"log10",gsl_complex_log10_wrap,METH_VARARGS},
{"log_b",gsl_complex_log_b_wrap,METH_VARARGS},
{"sin",gsl_complex_sin_wrap,METH_VARARGS},
{"cos",gsl_complex_cos_wrap,METH_VARARGS},
{"sec",gsl_complex_sec_wrap,METH_VARARGS},
{"csc",gsl_complex_csc_wrap,METH_VARARGS},
{"tan",gsl_complex_tan_wrap,METH_VARARGS},
{"cot",gsl_complex_cot_wrap,METH_VARARGS},
{"arcsin",gsl_complex_arcsin_wrap,METH_VARARGS},
{"arcsin_real",gsl_complex_arcsin_real_wrap,METH_VARARGS},
{"arccos",gsl_complex_arccos_wrap,METH_VARARGS},
{"arccos_real",gsl_complex_arccos_real_wrap,METH_VARARGS},
{"arcsec",gsl_complex_arcsec_wrap,METH_VARARGS},
{"arcsec_real",gsl_complex_arcsec_real_wrap,METH_VARARGS},
{"arccsc",gsl_complex_arccsc_wrap,METH_VARARGS},
{"arccsc_real",gsl_complex_arccsc_real_wrap,METH_VARARGS},
{"arctan",gsl_complex_arctan_wrap,METH_VARARGS},
{"arccot",gsl_complex_arccot_wrap,METH_VARARGS},
{"sinh",gsl_complex_sinh_wrap,METH_VARARGS},
{"cosh",gsl_complex_cosh_wrap,METH_VARARGS},
{"sech",gsl_complex_sech_wrap,METH_VARARGS},
{"csch",gsl_complex_csch_wrap,METH_VARARGS},
{"tanh",gsl_complex_tanh_wrap,METH_VARARGS},
{"coth",gsl_complex_coth_wrap,METH_VARARGS},
{"arcsinh",gsl_complex_arcsinh_wrap,METH_VARARGS},
{"arccosh",gsl_complex_arccosh_wrap,METH_VARARGS},
{"arccosh_real",gsl_complex_arccosh_real_wrap,METH_VARARGS},
{"arcsech",gsl_complex_arcsech_wrap,METH_VARARGS},
{"arccsch",gsl_complex_arccsch_wrap,METH_VARARGS},
{"arctanh",gsl_complex_arctanh_wrap,METH_VARARGS},
{"arctanh_real",gsl_complex_arctanh_real_wrap,METH_VARARGS},
{"arccoth",gsl_complex_arccoth_wrap,METH_VARARGS},
{"airy_Ai_e",gsl_sf_airy_Ai_e_wrap,METH_VARARGS},
{"airy_Ai",gsl_sf_airy_Ai_wrap,METH_VARARGS},
{"airy_Bi_e",gsl_sf_airy_Bi_e_wrap,METH_VARARGS},
{"airy_Bi",gsl_sf_airy_Bi_wrap,METH_VARARGS},
{"airy_Ai_scaled_e",gsl_sf_airy_Ai_scaled_e_wrap,METH_VARARGS},
{"airy_Ai_scaled",gsl_sf_airy_Ai_scaled_wrap,METH_VARARGS},
{"airy_Bi_scaled_e",gsl_sf_airy_Bi_scaled_e_wrap,METH_VARARGS},
{"airy_Bi_scaled",gsl_sf_airy_Bi_scaled_wrap,METH_VARARGS},
{"airy_Ai_deriv_e",gsl_sf_airy_Ai_deriv_e_wrap,METH_VARARGS},
{"airy_Ai_deriv",gsl_sf_airy_Ai_deriv_wrap,METH_VARARGS},
{"airy_Bi_deriv_e",gsl_sf_airy_Bi_deriv_e_wrap,METH_VARARGS},
{"airy_Bi_deriv",gsl_sf_airy_Bi_deriv_wrap,METH_VARARGS},
{"airy_Ai_deriv_scaled_e",gsl_sf_airy_Ai_deriv_scaled_e_wrap,METH_VARARGS},
{"airy_Ai_deriv_scaled",gsl_sf_airy_Ai_deriv_scaled_wrap,METH_VARARGS},
{"airy_Bi_deriv_scaled_e",gsl_sf_airy_Bi_deriv_scaled_e_wrap,METH_VARARGS},
{"airy_Bi_deriv_scaled",gsl_sf_airy_Bi_deriv_scaled_wrap,METH_VARARGS},
{"airy_zero_Ai_e",gsl_sf_airy_zero_Ai_e_wrap,METH_VARARGS},
{"airy_zero_Ai",gsl_sf_airy_zero_Ai_wrap,METH_VARARGS},
{"airy_zero_Bi_e",gsl_sf_airy_zero_Bi_e_wrap,METH_VARARGS},
{"airy_zero_Bi",gsl_sf_airy_zero_Bi_wrap,METH_VARARGS},
{"airy_zero_Ai_deriv_e",gsl_sf_airy_zero_Ai_deriv_e_wrap,METH_VARARGS},
{"airy_zero_Ai_deriv",gsl_sf_airy_zero_Ai_deriv_wrap,METH_VARARGS},
{"airy_zero_Bi_deriv_e",gsl_sf_airy_zero_Bi_deriv_e_wrap,METH_VARARGS},
{"airy_zero_Bi_deriv",gsl_sf_airy_zero_Bi_deriv_wrap,METH_VARARGS},
{"bessel_J0_e",gsl_sf_bessel_J0_e_wrap,METH_VARARGS},
{"bessel_J0",gsl_sf_bessel_J0_wrap,METH_VARARGS},
{"bessel_J1_e",gsl_sf_bessel_J1_e_wrap,METH_VARARGS},
{"bessel_J1",gsl_sf_bessel_J1_wrap,METH_VARARGS},
{"bessel_Jn_e",gsl_sf_bessel_Jn_e_wrap,METH_VARARGS},
{"bessel_Jn",gsl_sf_bessel_Jn_wrap,METH_VARARGS},
{"bessel_Y0_e",gsl_sf_bessel_Y0_e_wrap,METH_VARARGS},
{"bessel_Y0",gsl_sf_bessel_Y0_wrap,METH_VARARGS},
{"bessel_Y1_e",gsl_sf_bessel_Y1_e_wrap,METH_VARARGS},
{"bessel_Y1",gsl_sf_bessel_Y1_wrap,METH_VARARGS},
{"bessel_Yn_e",gsl_sf_bessel_Yn_e_wrap,METH_VARARGS},
{"bessel_Yn",gsl_sf_bessel_Yn_wrap,METH_VARARGS},
{"bessel_I0_e",gsl_sf_bessel_I0_e_wrap,METH_VARARGS},
{"bessel_I0",gsl_sf_bessel_I0_wrap,METH_VARARGS},
{"bessel_I1_e",gsl_sf_bessel_I1_e_wrap,METH_VARARGS},
{"bessel_I1",gsl_sf_bessel_I1_wrap,METH_VARARGS},
{"bessel_In_e",gsl_sf_bessel_In_e_wrap,METH_VARARGS},
{"bessel_In",gsl_sf_bessel_In_wrap,METH_VARARGS},
{"bessel_I0_scaled_e",gsl_sf_bessel_I0_scaled_e_wrap,METH_VARARGS},
{"bessel_I0_scaled",gsl_sf_bessel_I0_scaled_wrap,METH_VARARGS},
{"bessel_I1_scaled_e",gsl_sf_bessel_I1_scaled_e_wrap,METH_VARARGS},
{"bessel_I1_scaled",gsl_sf_bessel_I1_scaled_wrap,METH_VARARGS},
{"bessel_In_scaled_e",gsl_sf_bessel_In_scaled_e_wrap,METH_VARARGS},
{"bessel_In_scaled",gsl_sf_bessel_In_scaled_wrap,METH_VARARGS},
{"bessel_K0_e",gsl_sf_bessel_K0_e_wrap,METH_VARARGS},
{"bessel_K0",gsl_sf_bessel_K0_wrap,METH_VARARGS},
{"bessel_K1_e",gsl_sf_bessel_K1_e_wrap,METH_VARARGS},
{"bessel_K1",gsl_sf_bessel_K1_wrap,METH_VARARGS},
{"bessel_Kn_e",gsl_sf_bessel_Kn_e_wrap,METH_VARARGS},
{"bessel_Kn",gsl_sf_bessel_Kn_wrap,METH_VARARGS},
{"bessel_K0_scaled_e",gsl_sf_bessel_K0_scaled_e_wrap,METH_VARARGS},
{"bessel_K0_scaled",gsl_sf_bessel_K0_scaled_wrap,METH_VARARGS},
{"bessel_K1_scaled_e",gsl_sf_bessel_K1_scaled_e_wrap,METH_VARARGS},
{"bessel_K1_scaled",gsl_sf_bessel_K1_scaled_wrap,METH_VARARGS},
{"bessel_Kn_scaled_e",gsl_sf_bessel_Kn_scaled_e_wrap,METH_VARARGS},
{"bessel_Kn_scaled",gsl_sf_bessel_Kn_scaled_wrap,METH_VARARGS},
{"bessel_j0_e",gsl_sf_bessel_j0_e_wrap,METH_VARARGS},
{"bessel_j0",gsl_sf_bessel_j0_wrap,METH_VARARGS},
{"bessel_j1_e",gsl_sf_bessel_j1_e_wrap,METH_VARARGS},
{"bessel_j1",gsl_sf_bessel_j1_wrap,METH_VARARGS},
{"bessel_j2_e",gsl_sf_bessel_j2_e_wrap,METH_VARARGS},
{"bessel_j2",gsl_sf_bessel_j2_wrap,METH_VARARGS},
{"bessel_jl_e",gsl_sf_bessel_jl_e_wrap,METH_VARARGS},
{"bessel_jl",gsl_sf_bessel_jl_wrap,METH_VARARGS},
{"bessel_y0_e",gsl_sf_bessel_y0_e_wrap,METH_VARARGS},
{"bessel_y0",gsl_sf_bessel_y0_wrap,METH_VARARGS},
{"bessel_y1_e",gsl_sf_bessel_y1_e_wrap,METH_VARARGS},
{"bessel_y1",gsl_sf_bessel_y1_wrap,METH_VARARGS},
{"bessel_y2_e",gsl_sf_bessel_y2_e_wrap,METH_VARARGS},
{"bessel_y2",gsl_sf_bessel_y2_wrap,METH_VARARGS},
{"bessel_yl_e",gsl_sf_bessel_yl_e_wrap,METH_VARARGS},
{"bessel_yl",gsl_sf_bessel_yl_wrap,METH_VARARGS},
{"bessel_i0_scaled_e",gsl_sf_bessel_i0_scaled_e_wrap,METH_VARARGS},
{"bessel_i0_scaled",gsl_sf_bessel_i0_scaled_wrap,METH_VARARGS},
{"bessel_i1_scaled_e",gsl_sf_bessel_i1_scaled_e_wrap,METH_VARARGS},
{"bessel_i1_scaled",gsl_sf_bessel_i1_scaled_wrap,METH_VARARGS},
{"bessel_i2_scaled_e",gsl_sf_bessel_i2_scaled_e_wrap,METH_VARARGS},
{"bessel_i2_scaled",gsl_sf_bessel_i2_scaled_wrap,METH_VARARGS},
{"bessel_il_scaled_e",gsl_sf_bessel_il_scaled_e_wrap,METH_VARARGS},
{"bessel_il_scaled",gsl_sf_bessel_il_scaled_wrap,METH_VARARGS},
{"bessel_k0_scaled_e",gsl_sf_bessel_k0_scaled_e_wrap,METH_VARARGS},
{"bessel_k0_scaled",gsl_sf_bessel_k0_scaled_wrap,METH_VARARGS},
{"bessel_k1_scaled_e",gsl_sf_bessel_k1_scaled_e_wrap,METH_VARARGS},
{"bessel_k1_scaled",gsl_sf_bessel_k1_scaled_wrap,METH_VARARGS},
{"bessel_k2_scaled_e",gsl_sf_bessel_k2_scaled_e_wrap,METH_VARARGS},
{"bessel_k2_scaled",gsl_sf_bessel_k2_scaled_wrap,METH_VARARGS},
{"bessel_kl_scaled_e",gsl_sf_bessel_kl_scaled_e_wrap,METH_VARARGS},
{"bessel_kl_scaled",gsl_sf_bessel_kl_scaled_wrap,METH_VARARGS},
{"bessel_Jnu_e",gsl_sf_bessel_Jnu_e_wrap,METH_VARARGS},
{"bessel_Jnu",gsl_sf_bessel_Jnu_wrap,METH_VARARGS},
{"bessel_Ynu_e",gsl_sf_bessel_Ynu_e_wrap,METH_VARARGS},
{"bessel_Ynu",gsl_sf_bessel_Ynu_wrap,METH_VARARGS},
{"bessel_Inu_scaled_e",gsl_sf_bessel_Inu_scaled_e_wrap,METH_VARARGS},
{"bessel_Inu_scaled",gsl_sf_bessel_Inu_scaled_wrap,METH_VARARGS},
{"bessel_Inu_e",gsl_sf_bessel_Inu_e_wrap,METH_VARARGS},
{"bessel_Inu",gsl_sf_bessel_Inu_wrap,METH_VARARGS},
{"bessel_Knu_scaled_e",gsl_sf_bessel_Knu_scaled_e_wrap,METH_VARARGS},
{"bessel_Knu_scaled",gsl_sf_bessel_Knu_scaled_wrap,METH_VARARGS},
{"bessel_Knu_scaled_e10_e",gsl_sf_bessel_Knu_scaled_e10_e_wrap,METH_VARARGS},
{"bessel_Knu_e",gsl_sf_bessel_Knu_e_wrap,METH_VARARGS},
{"bessel_Knu",gsl_sf_bessel_Knu_wrap,METH_VARARGS},
{"bessel_lnKnu_e",gsl_sf_bessel_lnKnu_e_wrap,METH_VARARGS},
{"bessel_lnKnu",gsl_sf_bessel_lnKnu_wrap,METH_VARARGS},
{"bessel_zero_J0_e",gsl_sf_bessel_zero_J0_e_wrap,METH_VARARGS},
{"bessel_zero_J0",gsl_sf_bessel_zero_J0_wrap,METH_VARARGS},
{"bessel_zero_J1_e",gsl_sf_bessel_zero_J1_e_wrap,METH_VARARGS},
{"bessel_zero_J1",gsl_sf_bessel_zero_J1_wrap,METH_VARARGS},
{"bessel_zero_Jnu_e",gsl_sf_bessel_zero_Jnu_e_wrap,METH_VARARGS},
{"bessel_zero_Jnu",gsl_sf_bessel_zero_Jnu_wrap,METH_VARARGS},
{"clausen_e",gsl_sf_clausen_e_wrap,METH_VARARGS},
{"clausen",gsl_sf_clausen_wrap,METH_VARARGS},
{"coupling_3j_e",gsl_sf_coupling_3j_e_wrap,METH_VARARGS},
{"coupling_3j",gsl_sf_coupling_3j_wrap,METH_VARARGS},
{"coupling_6j_e",gsl_sf_coupling_6j_e_wrap,METH_VARARGS},
{"coupling_6j",gsl_sf_coupling_6j_wrap,METH_VARARGS},
{"coupling_RacahW_e",gsl_sf_coupling_RacahW_e_wrap,METH_VARARGS},
{"coupling_RacahW",gsl_sf_coupling_RacahW_wrap,METH_VARARGS},
{"coupling_9j_e",gsl_sf_coupling_9j_e_wrap,METH_VARARGS},
{"coupling_9j",gsl_sf_coupling_9j_wrap,METH_VARARGS},
{"coupling_6j_INCORRECT",gsl_sf_coupling_6j_INCORRECT_wrap,METH_VARARGS},
{"hydrogenicR_1_e",gsl_sf_hydrogenicR_1_e_wrap,METH_VARARGS},
{"hydrogenicR_1",gsl_sf_hydrogenicR_1_wrap,METH_VARARGS},
{"hydrogenicR_e",gsl_sf_hydrogenicR_e_wrap,METH_VARARGS},
{"hydrogenicR",gsl_sf_hydrogenicR_wrap,METH_VARARGS},
{"coulomb_wave_FG_e",gsl_sf_coulomb_wave_FG_e_wrap,METH_VARARGS},
{"coulomb_CL_e",gsl_sf_coulomb_CL_e_wrap,METH_VARARGS},
{"dawson_e",gsl_sf_dawson_e_wrap,METH_VARARGS},
{"dawson",gsl_sf_dawson_wrap,METH_VARARGS},
{"debye_1_e",gsl_sf_debye_1_e_wrap,METH_VARARGS},
{"debye_1",gsl_sf_debye_1_wrap,METH_VARARGS},
{"debye_2_e",gsl_sf_debye_2_e_wrap,METH_VARARGS},
{"debye_2",gsl_sf_debye_2_wrap,METH_VARARGS},
{"debye_3_e",gsl_sf_debye_3_e_wrap,METH_VARARGS},
{"debye_3",gsl_sf_debye_3_wrap,METH_VARARGS},
{"debye_4_e",gsl_sf_debye_4_e_wrap,METH_VARARGS},
{"debye_4",gsl_sf_debye_4_wrap,METH_VARARGS},
{"debye_5_e",gsl_sf_debye_5_e_wrap,METH_VARARGS},
{"debye_5",gsl_sf_debye_5_wrap,METH_VARARGS},
{"debye_6_e",gsl_sf_debye_6_e_wrap,METH_VARARGS},
{"debye_6",gsl_sf_debye_6_wrap,METH_VARARGS},
{"dilog_e",gsl_sf_dilog_e_wrap,METH_VARARGS},
{"dilog",gsl_sf_dilog_wrap,METH_VARARGS},
{"complex_dilog_xy_e",gsl_sf_complex_dilog_xy_e_wrap,METH_VARARGS},
{"complex_spence_xy_e",gsl_sf_complex_spence_xy_e_wrap,METH_VARARGS},
{"multiply_e",gsl_sf_multiply_e_wrap,METH_VARARGS},
{"multiply",gsl_sf_multiply_wrap,METH_VARARGS},
{"multiply_err_e",gsl_sf_multiply_err_e_wrap,METH_VARARGS},
{"ellint_Kcomp_e",gsl_sf_ellint_Kcomp_e_wrap,METH_VARARGS},
{"ellint_Kcomp",gsl_sf_ellint_Kcomp_wrap,METH_VARARGS},
{"ellint_Ecomp_e",gsl_sf_ellint_Ecomp_e_wrap,METH_VARARGS},
{"ellint_Ecomp",gsl_sf_ellint_Ecomp_wrap,METH_VARARGS},
{"ellint_Pcomp_e",gsl_sf_ellint_Pcomp_e_wrap,METH_VARARGS},
{"ellint_Pcomp",gsl_sf_ellint_Pcomp_wrap,METH_VARARGS},
{"ellint_Dcomp_e",gsl_sf_ellint_Dcomp_e_wrap,METH_VARARGS},
{"ellint_Dcomp",gsl_sf_ellint_Dcomp_wrap,METH_VARARGS},
{"ellint_F_e",gsl_sf_ellint_F_e_wrap,METH_VARARGS},
{"ellint_F",gsl_sf_ellint_F_wrap,METH_VARARGS},
{"ellint_E_e",gsl_sf_ellint_E_e_wrap,METH_VARARGS},
{"ellint_E",gsl_sf_ellint_E_wrap,METH_VARARGS},
{"ellint_P_e",gsl_sf_ellint_P_e_wrap,METH_VARARGS},
{"ellint_P",gsl_sf_ellint_P_wrap,METH_VARARGS},
{"ellint_D_e",gsl_sf_ellint_D_e_wrap,METH_VARARGS},
{"ellint_D",gsl_sf_ellint_D_wrap,METH_VARARGS},
{"ellint_RC_e",gsl_sf_ellint_RC_e_wrap,METH_VARARGS},
{"ellint_RC",gsl_sf_ellint_RC_wrap,METH_VARARGS},
{"ellint_RD_e",gsl_sf_ellint_RD_e_wrap,METH_VARARGS},
{"ellint_RD",gsl_sf_ellint_RD_wrap,METH_VARARGS},
{"ellint_RF_e",gsl_sf_ellint_RF_e_wrap,METH_VARARGS},
{"ellint_RF",gsl_sf_ellint_RF_wrap,METH_VARARGS},
{"ellint_RJ_e",gsl_sf_ellint_RJ_e_wrap,METH_VARARGS},
{"ellint_RJ",gsl_sf_ellint_RJ_wrap,METH_VARARGS},
{"elljac_e",gsl_sf_elljac_e_wrap,METH_VARARGS},
{"erfc_e",gsl_sf_erfc_e_wrap,METH_VARARGS},
{"erfc",gsl_sf_erfc_wrap,METH_VARARGS},
{"log_erfc_e",gsl_sf_log_erfc_e_wrap,METH_VARARGS},
{"log_erfc",gsl_sf_log_erfc_wrap,METH_VARARGS},
{"erf_e",gsl_sf_erf_e_wrap,METH_VARARGS},
{"erf",gsl_sf_erf_wrap,METH_VARARGS},
{"erf_Z_e",gsl_sf_erf_Z_e_wrap,METH_VARARGS},
{"erf_Q_e",gsl_sf_erf_Q_e_wrap,METH_VARARGS},
{"erf_Z",gsl_sf_erf_Z_wrap,METH_VARARGS},
{"erf_Q",gsl_sf_erf_Q_wrap,METH_VARARGS},
{"hazard_e",gsl_sf_hazard_e_wrap,METH_VARARGS},
{"hazard",gsl_sf_hazard_wrap,METH_VARARGS},
{"exp_e",gsl_sf_exp_e_wrap,METH_VARARGS},
{"exp",gsl_sf_exp_wrap,METH_VARARGS},
{"exp_e10_e",gsl_sf_exp_e10_e_wrap,METH_VARARGS},
{"exp_mult_e",gsl_sf_exp_mult_e_wrap,METH_VARARGS},
{"exp_mult",gsl_sf_exp_mult_wrap,METH_VARARGS},
{"exp_mult_e10_e",gsl_sf_exp_mult_e10_e_wrap,METH_VARARGS},
{"expm1_e",gsl_sf_expm1_e_wrap,METH_VARARGS},
{"expm1",gsl_sf_expm1_wrap,METH_VARARGS},
{"exprel_e",gsl_sf_exprel_e_wrap,METH_VARARGS},
{"exprel",gsl_sf_exprel_wrap,METH_VARARGS},
{"exprel_2_e",gsl_sf_exprel_2_e_wrap,METH_VARARGS},
{"exprel_2",gsl_sf_exprel_2_wrap,METH_VARARGS},
{"exprel_n_e",gsl_sf_exprel_n_e_wrap,METH_VARARGS},
{"exprel_n",gsl_sf_exprel_n_wrap,METH_VARARGS},
{"exprel_n_CF_e",gsl_sf_exprel_n_CF_e_wrap,METH_VARARGS},
{"exp_err_e",gsl_sf_exp_err_e_wrap,METH_VARARGS},
{"exp_err_e10_e",gsl_sf_exp_err_e10_e_wrap,METH_VARARGS},
{"exp_mult_err_e",gsl_sf_exp_mult_err_e_wrap,METH_VARARGS},
{"exp_mult_err_e10_e",gsl_sf_exp_mult_err_e10_e_wrap,METH_VARARGS},
{"expint_E1_e",gsl_sf_expint_E1_e_wrap,METH_VARARGS},
{"expint_E1",gsl_sf_expint_E1_wrap,METH_VARARGS},
{"expint_E2_e",gsl_sf_expint_E2_e_wrap,METH_VARARGS},
{"expint_E2",gsl_sf_expint_E2_wrap,METH_VARARGS},
{"expint_En_e",gsl_sf_expint_En_e_wrap,METH_VARARGS},
{"expint_En",gsl_sf_expint_En_wrap,METH_VARARGS},
{"expint_E1_scaled_e",gsl_sf_expint_E1_scaled_e_wrap,METH_VARARGS},
{"expint_E1_scaled",gsl_sf_expint_E1_scaled_wrap,METH_VARARGS},
{"expint_E2_scaled_e",gsl_sf_expint_E2_scaled_e_wrap,METH_VARARGS},
{"expint_E2_scaled",gsl_sf_expint_E2_scaled_wrap,METH_VARARGS},
{"expint_En_scaled_e",gsl_sf_expint_En_scaled_e_wrap,METH_VARARGS},
{"expint_En_scaled",gsl_sf_expint_En_scaled_wrap,METH_VARARGS},
{"expint_Ei_e",gsl_sf_expint_Ei_e_wrap,METH_VARARGS},
{"expint_Ei",gsl_sf_expint_Ei_wrap,METH_VARARGS},
{"expint_Ei_scaled_e",gsl_sf_expint_Ei_scaled_e_wrap,METH_VARARGS},
{"expint_Ei_scaled",gsl_sf_expint_Ei_scaled_wrap,METH_VARARGS},
{"Shi_e",gsl_sf_Shi_e_wrap,METH_VARARGS},
{"Shi",gsl_sf_Shi_wrap,METH_VARARGS},
{"Chi_e",gsl_sf_Chi_e_wrap,METH_VARARGS},
{"Chi",gsl_sf_Chi_wrap,METH_VARARGS},
{"expint_3_e",gsl_sf_expint_3_e_wrap,METH_VARARGS},
{"expint_3",gsl_sf_expint_3_wrap,METH_VARARGS},
{"Si_e",gsl_sf_Si_e_wrap,METH_VARARGS},
{"Si",gsl_sf_Si_wrap,METH_VARARGS},
{"Ci_e",gsl_sf_Ci_e_wrap,METH_VARARGS},
{"Ci",gsl_sf_Ci_wrap,METH_VARARGS},
{"atanint_e",gsl_sf_atanint_e_wrap,METH_VARARGS},
{"atanint",gsl_sf_atanint_wrap,METH_VARARGS},
{"fermi_dirac_m1_e",gsl_sf_fermi_dirac_m1_e_wrap,METH_VARARGS},
{"fermi_dirac_m1",gsl_sf_fermi_dirac_m1_wrap,METH_VARARGS},
{"fermi_dirac_0_e",gsl_sf_fermi_dirac_0_e_wrap,METH_VARARGS},
{"fermi_dirac_0",gsl_sf_fermi_dirac_0_wrap,METH_VARARGS},
{"fermi_dirac_1_e",gsl_sf_fermi_dirac_1_e_wrap,METH_VARARGS},
{"fermi_dirac_1",gsl_sf_fermi_dirac_1_wrap,METH_VARARGS},
{"fermi_dirac_2_e",gsl_sf_fermi_dirac_2_e_wrap,METH_VARARGS},
{"fermi_dirac_2",gsl_sf_fermi_dirac_2_wrap,METH_VARARGS},
{"fermi_dirac_int_e",gsl_sf_fermi_dirac_int_e_wrap,METH_VARARGS},
{"fermi_dirac_int",gsl_sf_fermi_dirac_int_wrap,METH_VARARGS},
{"fermi_dirac_mhalf_e",gsl_sf_fermi_dirac_mhalf_e_wrap,METH_VARARGS},
{"fermi_dirac_mhalf",gsl_sf_fermi_dirac_mhalf_wrap,METH_VARARGS},
{"fermi_dirac_half_e",gsl_sf_fermi_dirac_half_e_wrap,METH_VARARGS},
{"fermi_dirac_half",gsl_sf_fermi_dirac_half_wrap,METH_VARARGS},
{"fermi_dirac_3half_e",gsl_sf_fermi_dirac_3half_e_wrap,METH_VARARGS},
{"fermi_dirac_3half",gsl_sf_fermi_dirac_3half_wrap,METH_VARARGS},
{"fermi_dirac_inc_0_e",gsl_sf_fermi_dirac_inc_0_e_wrap,METH_VARARGS},
{"fermi_dirac_inc_0",gsl_sf_fermi_dirac_inc_0_wrap,METH_VARARGS},
{"lngamma_e",gsl_sf_lngamma_e_wrap,METH_VARARGS},
{"lngamma",gsl_sf_lngamma_wrap,METH_VARARGS},
{"lngamma_sgn_e",gsl_sf_lngamma_sgn_e_wrap,METH_VARARGS},
{"gamma_e",gsl_sf_gamma_e_wrap,METH_VARARGS},
{"gamma",gsl_sf_gamma_wrap,METH_VARARGS},
{"gammastar_e",gsl_sf_gammastar_e_wrap,METH_VARARGS},
{"gammastar",gsl_sf_gammastar_wrap,METH_VARARGS},
{"gammainv_e",gsl_sf_gammainv_e_wrap,METH_VARARGS},
{"gammainv",gsl_sf_gammainv_wrap,METH_VARARGS},
{"taylorcoeff_e",gsl_sf_taylorcoeff_e_wrap,METH_VARARGS},
{"taylorcoeff",gsl_sf_taylorcoeff_wrap,METH_VARARGS},
{"fact_e",gsl_sf_fact_e_wrap,METH_VARARGS},
{"fact",gsl_sf_fact_wrap,METH_VARARGS},
{"doublefact_e",gsl_sf_doublefact_e_wrap,METH_VARARGS},
{"doublefact",gsl_sf_doublefact_wrap,METH_VARARGS},
{"lnfact_e",gsl_sf_lnfact_e_wrap,METH_VARARGS},
{"lnfact",gsl_sf_lnfact_wrap,METH_VARARGS},
{"lndoublefact_e",gsl_sf_lndoublefact_e_wrap,METH_VARARGS},
{"lndoublefact",gsl_sf_lndoublefact_wrap,METH_VARARGS},
{"lnchoose_e",gsl_sf_lnchoose_e_wrap,METH_VARARGS},
{"lnchoose",gsl_sf_lnchoose_wrap,METH_VARARGS},
{"choose_e",gsl_sf_choose_e_wrap,METH_VARARGS},
{"choose",gsl_sf_choose_wrap,METH_VARARGS},
{"lnpoch_e",gsl_sf_lnpoch_e_wrap,METH_VARARGS},
{"lnpoch",gsl_sf_lnpoch_wrap,METH_VARARGS},
{"lnpoch_sgn_e",gsl_sf_lnpoch_sgn_e_wrap,METH_VARARGS},
{"poch_e",gsl_sf_poch_e_wrap,METH_VARARGS},
{"poch",gsl_sf_poch_wrap,METH_VARARGS},
{"pochrel_e",gsl_sf_pochrel_e_wrap,METH_VARARGS},
{"pochrel",gsl_sf_pochrel_wrap,METH_VARARGS},
{"gamma_inc_Q_e",gsl_sf_gamma_inc_Q_e_wrap,METH_VARARGS},
{"gamma_inc_Q",gsl_sf_gamma_inc_Q_wrap,METH_VARARGS},
{"gamma_inc_P_e",gsl_sf_gamma_inc_P_e_wrap,METH_VARARGS},
{"gamma_inc_P",gsl_sf_gamma_inc_P_wrap,METH_VARARGS},
{"gamma_inc_e",gsl_sf_gamma_inc_e_wrap,METH_VARARGS},
{"gamma_inc",gsl_sf_gamma_inc_wrap,METH_VARARGS},
{"lnbeta_e",gsl_sf_lnbeta_e_wrap,METH_VARARGS},
{"lnbeta",gsl_sf_lnbeta_wrap,METH_VARARGS},
{"lnbeta_sgn_e",gsl_sf_lnbeta_sgn_e_wrap,METH_VARARGS},
{"beta_e",gsl_sf_beta_e_wrap,METH_VARARGS},
{"beta",gsl_sf_beta_wrap,METH_VARARGS},
{"beta_inc_e",gsl_sf_beta_inc_e_wrap,METH_VARARGS},
{"beta_inc",gsl_sf_beta_inc_wrap,METH_VARARGS},
{"gegenpoly_1_e",gsl_sf_gegenpoly_1_e_wrap,METH_VARARGS},
{"gegenpoly_2_e",gsl_sf_gegenpoly_2_e_wrap,METH_VARARGS},
{"gegenpoly_3_e",gsl_sf_gegenpoly_3_e_wrap,METH_VARARGS},
{"gegenpoly_1",gsl_sf_gegenpoly_1_wrap,METH_VARARGS},
{"gegenpoly_2",gsl_sf_gegenpoly_2_wrap,METH_VARARGS},
{"gegenpoly_3",gsl_sf_gegenpoly_3_wrap,METH_VARARGS},
{"gegenpoly_n_e",gsl_sf_gegenpoly_n_e_wrap,METH_VARARGS},
{"gegenpoly_n",gsl_sf_gegenpoly_n_wrap,METH_VARARGS},
{"hyperg_0F1_e",gsl_sf_hyperg_0F1_e_wrap,METH_VARARGS},
{"hyperg_0F1",gsl_sf_hyperg_0F1_wrap,METH_VARARGS},
{"hyperg_1F1_int_e",gsl_sf_hyperg_1F1_int_e_wrap,METH_VARARGS},
{"hyperg_1F1_int",gsl_sf_hyperg_1F1_int_wrap,METH_VARARGS},
{"hyperg_1F1_e",gsl_sf_hyperg_1F1_e_wrap,METH_VARARGS},
{"hyperg_1F1",gsl_sf_hyperg_1F1_wrap,METH_VARARGS},
{"hyperg_U_int_e",gsl_sf_hyperg_U_int_e_wrap,METH_VARARGS},
{"hyperg_U_int",gsl_sf_hyperg_U_int_wrap,METH_VARARGS},
{"hyperg_U_int_e10_e",gsl_sf_hyperg_U_int_e10_e_wrap,METH_VARARGS},
{"hyperg_U_e",gsl_sf_hyperg_U_e_wrap,METH_VARARGS},
{"hyperg_U",gsl_sf_hyperg_U_wrap,METH_VARARGS},
{"hyperg_U_e10_e",gsl_sf_hyperg_U_e10_e_wrap,METH_VARARGS},
{"hyperg_2F1_e",gsl_sf_hyperg_2F1_e_wrap,METH_VARARGS},
{"hyperg_2F1",gsl_sf_hyperg_2F1_wrap,METH_VARARGS},
{"hyperg_2F1_conj_e",gsl_sf_hyperg_2F1_conj_e_wrap,METH_VARARGS},
{"hyperg_2F1_conj",gsl_sf_hyperg_2F1_conj_wrap,METH_VARARGS},
{"hyperg_2F1_renorm_e",gsl_sf_hyperg_2F1_renorm_e_wrap,METH_VARARGS},
{"hyperg_2F1_renorm",gsl_sf_hyperg_2F1_renorm_wrap,METH_VARARGS},
{"hyperg_2F1_conj_renorm_e",gsl_sf_hyperg_2F1_conj_renorm_e_wrap,METH_VARARGS},
{"hyperg_2F1_conj_renorm",gsl_sf_hyperg_2F1_conj_renorm_wrap,METH_VARARGS},
{"hyperg_2F0_e",gsl_sf_hyperg_2F0_e_wrap,METH_VARARGS},
{"hyperg_2F0",gsl_sf_hyperg_2F0_wrap,METH_VARARGS},
{"laguerre_1_e",gsl_sf_laguerre_1_e_wrap,METH_VARARGS},
{"laguerre_2_e",gsl_sf_laguerre_2_e_wrap,METH_VARARGS},
{"laguerre_3_e",gsl_sf_laguerre_3_e_wrap,METH_VARARGS},
{"laguerre_1",gsl_sf_laguerre_1_wrap,METH_VARARGS},
{"laguerre_2",gsl_sf_laguerre_2_wrap,METH_VARARGS},
{"laguerre_3",gsl_sf_laguerre_3_wrap,METH_VARARGS},
{"laguerre_n_e",gsl_sf_laguerre_n_e_wrap,METH_VARARGS},
{"laguerre_n",gsl_sf_laguerre_n_wrap,METH_VARARGS},
{"lambert_W0_e",gsl_sf_lambert_W0_e_wrap,METH_VARARGS},
{"lambert_W0",gsl_sf_lambert_W0_wrap,METH_VARARGS},
{"lambert_Wm1_e",gsl_sf_lambert_Wm1_e_wrap,METH_VARARGS},
{"lambert_Wm1",gsl_sf_lambert_Wm1_wrap,METH_VARARGS},
{"legendre_Pl_e",gsl_sf_legendre_Pl_e_wrap,METH_VARARGS},
{"legendre_Pl",gsl_sf_legendre_Pl_wrap,METH_VARARGS},
{"legendre_P1_e",gsl_sf_legendre_P1_e_wrap,METH_VARARGS},
{"legendre_P2_e",gsl_sf_legendre_P2_e_wrap,METH_VARARGS},
{"legendre_P3_e",gsl_sf_legendre_P3_e_wrap,METH_VARARGS},
{"legendre_P1",gsl_sf_legendre_P1_wrap,METH_VARARGS},
{"legendre_P2",gsl_sf_legendre_P2_wrap,METH_VARARGS},
{"legendre_P3",gsl_sf_legendre_P3_wrap,METH_VARARGS},
{"legendre_Q0_e",gsl_sf_legendre_Q0_e_wrap,METH_VARARGS},
{"legendre_Q0",gsl_sf_legendre_Q0_wrap,METH_VARARGS},
{"legendre_Q1_e",gsl_sf_legendre_Q1_e_wrap,METH_VARARGS},
{"legendre_Q1",gsl_sf_legendre_Q1_wrap,METH_VARARGS},
{"legendre_Ql_e",gsl_sf_legendre_Ql_e_wrap,METH_VARARGS},
{"legendre_Ql",gsl_sf_legendre_Ql_wrap,METH_VARARGS},
{"legendre_Plm_e",gsl_sf_legendre_Plm_e_wrap,METH_VARARGS},
{"legendre_Plm",gsl_sf_legendre_Plm_wrap,METH_VARARGS},
{"legendre_sphPlm_e",gsl_sf_legendre_sphPlm_e_wrap,METH_VARARGS},
{"legendre_sphPlm",gsl_sf_legendre_sphPlm_wrap,METH_VARARGS},
{"conicalP_half_e",gsl_sf_conicalP_half_e_wrap,METH_VARARGS},
{"conicalP_half",gsl_sf_conicalP_half_wrap,METH_VARARGS},
{"conicalP_mhalf_e",gsl_sf_conicalP_mhalf_e_wrap,METH_VARARGS},
{"conicalP_mhalf",gsl_sf_conicalP_mhalf_wrap,METH_VARARGS},
{"conicalP_0_e",gsl_sf_conicalP_0_e_wrap,METH_VARARGS},
{"conicalP_0",gsl_sf_conicalP_0_wrap,METH_VARARGS},
{"conicalP_1_e",gsl_sf_conicalP_1_e_wrap,METH_VARARGS},
{"conicalP_1",gsl_sf_conicalP_1_wrap,METH_VARARGS},
{"conicalP_sph_reg_e",gsl_sf_conicalP_sph_reg_e_wrap,METH_VARARGS},
{"conicalP_sph_reg",gsl_sf_conicalP_sph_reg_wrap,METH_VARARGS},
{"conicalP_cyl_reg_e",gsl_sf_conicalP_cyl_reg_e_wrap,METH_VARARGS},
{"conicalP_cyl_reg",gsl_sf_conicalP_cyl_reg_wrap,METH_VARARGS},
{"legendre_H3d_0_e",gsl_sf_legendre_H3d_0_e_wrap,METH_VARARGS},
{"legendre_H3d_0",gsl_sf_legendre_H3d_0_wrap,METH_VARARGS},
{"legendre_H3d_1_e",gsl_sf_legendre_H3d_1_e_wrap,METH_VARARGS},
{"legendre_H3d_1",gsl_sf_legendre_H3d_1_wrap,METH_VARARGS},
{"legendre_H3d_e",gsl_sf_legendre_H3d_e_wrap,METH_VARARGS},
{"legendre_H3d",gsl_sf_legendre_H3d_wrap,METH_VARARGS},
{"log_e",gsl_sf_log_e_wrap,METH_VARARGS},
{"log",gsl_sf_log_wrap,METH_VARARGS},
{"log_abs_e",gsl_sf_log_abs_e_wrap,METH_VARARGS},
{"log_abs",gsl_sf_log_abs_wrap,METH_VARARGS},
{"log_1plusx_e",gsl_sf_log_1plusx_e_wrap,METH_VARARGS},
{"log_1plusx",gsl_sf_log_1plusx_wrap,METH_VARARGS},
{"log_1plusx_mx_e",gsl_sf_log_1plusx_mx_e_wrap,METH_VARARGS},
{"log_1plusx_mx",gsl_sf_log_1plusx_mx_wrap,METH_VARARGS},
{"mathieu_a_e",gsl_sf_mathieu_a_e_wrap,METH_VARARGS},
{"mathieu_a",gsl_sf_mathieu_a_wrap,METH_VARARGS},
{"mathieu_b_e",gsl_sf_mathieu_b_e_wrap,METH_VARARGS},
{"mathieu_b",gsl_sf_mathieu_b_wrap,METH_VARARGS},
{"mathieu_a_coeff",gsl_sf_mathieu_a_coeff_wrap,METH_VARARGS},
{"mathieu_b_coeff",gsl_sf_mathieu_b_coeff_wrap,METH_VARARGS},
{"mathieu_ce",gsl_sf_mathieu_ce_wrap,METH_VARARGS},
{"mathieu_se_e",gsl_sf_mathieu_se_e_wrap,METH_VARARGS},
{"mathieu_se",gsl_sf_mathieu_se_wrap,METH_VARARGS},
{"mathieu_Mc_e",gsl_sf_mathieu_Mc_e_wrap,METH_VARARGS},
{"mathieu_Mc",gsl_sf_mathieu_Mc_wrap,METH_VARARGS},
{"mathieu_Ms_e",gsl_sf_mathieu_Ms_e_wrap,METH_VARARGS},
{"mathieu_Ms",gsl_sf_mathieu_Ms_wrap,METH_VARARGS},
{"pow_int_e",gsl_sf_pow_int_e_wrap,METH_VARARGS},
{"pow_int",gsl_sf_pow_int_wrap,METH_VARARGS},
{"psi_int_e",gsl_sf_psi_int_e_wrap,METH_VARARGS},
{"psi_int",gsl_sf_psi_int_wrap,METH_VARARGS},
{"psi_e",gsl_sf_psi_e_wrap,METH_VARARGS},
{"psi",gsl_sf_psi_wrap,METH_VARARGS},
{"psi_1piy_e",gsl_sf_psi_1piy_e_wrap,METH_VARARGS},
{"psi_1piy",gsl_sf_psi_1piy_wrap,METH_VARARGS},
{"complex_psi_e",gsl_sf_complex_psi_e_wrap,METH_VARARGS},
{"psi_1_int_e",gsl_sf_psi_1_int_e_wrap,METH_VARARGS},
{"psi_1_int",gsl_sf_psi_1_int_wrap,METH_VARARGS},
{"psi_1_e",gsl_sf_psi_1_e_wrap,METH_VARARGS},
{"psi_1",gsl_sf_psi_1_wrap,METH_VARARGS},
{"psi_n_e",gsl_sf_psi_n_e_wrap,METH_VARARGS},
{"psi_n",gsl_sf_psi_n_wrap,METH_VARARGS},
{"synchrotron_1_e",gsl_sf_synchrotron_1_e_wrap,METH_VARARGS},
{"synchrotron_1",gsl_sf_synchrotron_1_wrap,METH_VARARGS},
{"synchrotron_2_e",gsl_sf_synchrotron_2_e_wrap,METH_VARARGS},
{"synchrotron_2",gsl_sf_synchrotron_2_wrap,METH_VARARGS},
{"transport_2_e",gsl_sf_transport_2_e_wrap,METH_VARARGS},
{"transport_2",gsl_sf_transport_2_wrap,METH_VARARGS},
{"transport_3_e",gsl_sf_transport_3_e_wrap,METH_VARARGS},
{"transport_3",gsl_sf_transport_3_wrap,METH_VARARGS},
{"transport_4_e",gsl_sf_transport_4_e_wrap,METH_VARARGS},
{"transport_4",gsl_sf_transport_4_wrap,METH_VARARGS},
{"transport_5_e",gsl_sf_transport_5_e_wrap,METH_VARARGS},
{"transport_5",gsl_sf_transport_5_wrap,METH_VARARGS},
{"sin_e",gsl_sf_sin_e_wrap,METH_VARARGS},
{"sin",gsl_sf_sin_wrap,METH_VARARGS},
{"cos_e",gsl_sf_cos_e_wrap,METH_VARARGS},
{"cos",gsl_sf_cos_wrap,METH_VARARGS},
{"hypot_e",gsl_sf_hypot_e_wrap,METH_VARARGS},
{"hypot",gsl_sf_hypot_wrap,METH_VARARGS},
{"sinc_e",gsl_sf_sinc_e_wrap,METH_VARARGS},
{"sinc",gsl_sf_sinc_wrap,METH_VARARGS},
{"lnsinh_e",gsl_sf_lnsinh_e_wrap,METH_VARARGS},
{"lnsinh",gsl_sf_lnsinh_wrap,METH_VARARGS},
{"lncosh_e",gsl_sf_lncosh_e_wrap,METH_VARARGS},
{"lncosh",gsl_sf_lncosh_wrap,METH_VARARGS},
{"sin_err_e",gsl_sf_sin_err_e_wrap,METH_VARARGS},
{"cos_err_e",gsl_sf_cos_err_e_wrap,METH_VARARGS},
{"angle_restrict_symm",gsl_sf_angle_restrict_symm_wrap,METH_VARARGS},
{"angle_restrict_pos",gsl_sf_angle_restrict_pos_wrap,METH_VARARGS},
{"angle_restrict_symm_err_e",gsl_sf_angle_restrict_symm_err_e_wrap,METH_VARARGS},
{"angle_restrict_pos_err_e",gsl_sf_angle_restrict_pos_err_e_wrap,METH_VARARGS},
{"zeta_int_e",gsl_sf_zeta_int_e_wrap,METH_VARARGS},
{"zeta_int",gsl_sf_zeta_int_wrap,METH_VARARGS},
{"zeta_e",gsl_sf_zeta_e_wrap,METH_VARARGS},
{"zeta",gsl_sf_zeta_wrap,METH_VARARGS},
{"zetam1_e",gsl_sf_zetam1_e_wrap,METH_VARARGS},
{"zetam1",gsl_sf_zetam1_wrap,METH_VARARGS},
{"zetam1_int_e",gsl_sf_zetam1_int_e_wrap,METH_VARARGS},
{"zetam1_int",gsl_sf_zetam1_int_wrap,METH_VARARGS},
{"hzeta_e",gsl_sf_hzeta_e_wrap,METH_VARARGS},
{"hzeta",gsl_sf_hzeta_wrap,METH_VARARGS},
{"eta_int_e",gsl_sf_eta_int_e_wrap,METH_VARARGS},
{"eta_int",gsl_sf_eta_int_wrap,METH_VARARGS},
{"eta_e",gsl_sf_eta_e_wrap,METH_VARARGS},
{"eta",gsl_sf_eta_wrap,METH_VARARGS},
